Skip to contents

Count the amount or percentage of NA in a table by column

Usage

count_na(dataset, percent = FALSE)

Arguments

dataset

A dataframe containing rainfall data from different gauges in its columns.

percent

logical, controls whether to calculate the amount or percentage of NA.

Value

A dataframe.