Skip to contents

This function extracts the file name without the extension from a file path. It is an internal function used in the unit_converter function.

Usage

file_name(path)

Arguments

path

A character string with the file path.

Value

A character string with the file name without the extension.