Trend Surface Interpolation into Targeded Points
Source:R/trend_surface_interpolation.R
ts_to_point.RdThis function make an interpolation whith the trend surface method where the user have to inform the polynome degree. The interpolation is made over the tageded points for all the serie on the input.