This function extracts the file name without the extension from a file path.
It is an internal function used in the unit_converter function.
This function extracts the file name without the extension from a file path.
It is an internal function used in the unit_converter function.