This function is a wrapper for the fillGap in the
hyfo hyfo package. The main idea here for this wrapping function
is to preserve the column names as they are in the dataset input.
See also
For more detail about the algorithm used to fill the gaps, please
see fillGap.