Extract the date from the layer names This function extracts the date from the layer names of a raster object.
Source:R/utils.R
names_to_date.RdExtract the date from the layer names This function extracts the date from the layer names of a raster object.