This function extracts the records position grid for the study area combining
with the DEM for every point
Usage
study_area_records(raster_model, roi, dem)
Arguments
- raster_model
One layer representing where the data wile be extracted
- roi
A shapefile delimiting the study area
- dem
An elevation raster for the study area