Export tables to txt or csv files
Arguments
- table
A table
data.framecontaining all the observations- folder_path
Character string of the folder where the file must be saved.
- first_date
Character string of the first date for the time series. This value is used to renaming the columns on every single file while saving. The actual name is used as the file names. The suggested format is
%y%m%d- file_extension
Character.
txtorcsv.